@@ -340,6 +340,7 @@ xdg_cache_thumbnail_save_image_data (TumblerThumbnail *thumbnail,
   const gchar       *dest_path;
   const gchar       *temp_path;
   gchar             *mtime_str;
+  guint64            mtime_int = (guint64) mtime;
   gint               width;
   gint               height;
 
@@ -389,7 +390,8 @@ xdg_cache_thumbnail_save_image_data (TumblerThumbnail *thumbnail,
   if (stream != NULL)
     {
       /* convert the modified time of the source URI to a string */
-      mtime_str = g_strdup_printf ("%.6f", mtime);
+      mtime_str = g_strdup_printf ("%" G_GUINT64_FORMAT ".%.6" G_GUINT32_FORMAT,
+                                   mtime_int, (guint32) (1.e6 * (mtime - mtime_int)));
 
       /* try to save the pixbuf */
       if (gdk_pixbuf_save_to_stream (dest_pixbuf, G_OUTPUT_STREAM (stream), "png",
